@@ -8,6 +8,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
 require Exporter;
 require DynaLoader;
 require AutoLoader;
+require Digest::MD5;
 
 @ISA = qw(Exporter DynaLoader);
 # Items to export into callers namespace by default. Note: do not export
@@ -19,7 +20,7 @@ require AutoLoader;
    NameSpace_URL
    NameSpace_X500
 );
-$VERSION = '1.149';
+$VERSION = '1.201';
 
 # Preloaded methods go here.
 
@@ -90,12 +91,11 @@ very extensively to uniquely identify classes, applications and components
 across network-connected systems.
 
 The algorithm for UUID generation, used by this extension, is described in the
-Internet Draft "UUIDs and GUIDs" by Paul J. Leach and Rich Salz
-(L<http://hegel.ittc.ku.edu/topics/internet/internet-drafts/draft-l/draft-leach-uuids-guids-01.txt>).
-It provides reasonably efficient and reliable framework for generating UUIDs
-and supports fairly high allocation rates -- 10 million per second per machine
--- and therefore is suitable for identifying both extremely short-lived and
-very persistent objects on a given system as well as across the network.
+Internet Draft "UUIDs and GUIDs" by Paul J. Leach and Rich Salz.  (See RFC
+4122.)  It provides reasonably efficient and reliable framework for generating
+UUIDs and supports fairly high allocation rates -- 10 million per second per
+machine -- and therefore is suitable for identifying both extremely short-lived
+and very persistent objects on a given system as well as across the network.
 
 This modules provides several methods to create a UUID:
  
@@ -180,10 +180,12 @@ Alexander Golomshtok <agolomsh@cpan.org>
 
 =head1 SEE ALSO
 
-The Internet Draft "UUIDs and GUIDs" by Paul J. Leach and Rich Salz:
-L<http://www.globecom.net/ietf/draft/draft-leach-uuids-guids-01.html>
+The Internet Draft "UUIDs and GUIDs" by Paul J. Leach and Rich Salz (RFC 4122)
+
 "Primary Key Reengineering Projects: The Problem" by Tom Johnston
 L<http://www.dmreview.com/editorial/dmreview/print_action.cfm?EdID=1866>
+
 "Primary Key Reengineering Projects: The Solution" by Tom Johnston
 L<http://www.dmreview.com/editorial/dmreview/print_action.cfm?EdID=2004>
+
 =cut
